clear all
set more off
set maxvar 10000
capt ssc install excelcol

cd "C:/Directory/Datasets and Codes" // Replace with directory of folder where files are saved plus "\Datasets and Codes" at the end

**************************************************
****** Tables not included ***********************
**************************************************

*Table 2, Table 42
//Clean surveys -- not included

*Table 6
//Data from R script

*Table 5, Table 39, Table 40
//No do file needed
//Table 5: only yes/no for comparisons of samples
//Table 39: only decribes the sampling frame used
//Table 40: survey weights only

*Table 73-85
//Regressions not descriptive statistics

**************************************************
****** Sample tables  ****************************
**************************************************

use "Sample_2018.dta", clear

*Table 1

putexcel set "Shell Tables", sheet("Table 1") modify

local col = 3

foreach c in cdi ghana{
	local row = 3
	
	sum A2 if A2 == 1 & `c' == 1
	local agg = `r(N)'

	excelcol `col'
	putexcel `r(column)'`row' = `agg', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	local row = `row' + 1

	sum A3 if A3 == 1  & `c' == 1
	local cocoa = `r(N)'
	local non_cocoa = `agg' - `cocoa'

	excelcol `col'
	putexcel `r(column)'`row' = `cocoa', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)

	local row = `row' + 2

	excelcol `col'
	putexcel `r(column)'`row' = `non_cocoa', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' + 1
}

**************************************************
****** Roster tables  ****************************
**************************************************

use "Roster_2008_2018.dta", clear

*Table 3
putexcel set "Shell Tables", sheet("Table 3") modify

local col = 4

foreach c in cdi ghana{
	local row = 3

	sum head_age if `c' == 1 & Year == 2018, detail
	local age_mean = `r(mean)'
	local age_med = `r(p50)'
	
	excelcol `col'
	putexcel `r(column)'`row' = `age_mean', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
			
	excelcol `col'
	putexcel `r(column)'`row' = `age_med', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)

	local row = `row' + 1
	
	sum head_gender if `c' == 1 & Year == 2018
	local N = `r(N)' 

	sum head_gender if head_gender == 1 & `c' == 1 & Year == 2018
	local male_N = `r(N)'
	local male_pct = `male_N'/`N'
	
	excelcol `col'
	putexcel `r(column)'`row' = `male_N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
			
	excelcol `col'
	putexcel `r(column)'`row' = `male_pct', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 1

	sum head_gender if head_gender == 2 & `c' == 1 & Year == 2018
	local female_N = `r(N)'
	local female_pct = `female_N'/`N'
	
	excelcol `col'
	putexcel `r(column)'`row' = `female_N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
			
	excelcol `col'
	putexcel `r(column)'`row' = `female_pct', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' + 1
}

*Table 35
putexcel set "Shell Tables", sheet("Table 35") modify
local col = 2

foreach country in all cdi ghana {

	local row = 4

	foreach var in age2 age3 age4 children {
					
		capture noisily svy: regress `var' dummy if `country'==1
		mat M = r(table)
			
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
			
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1
		local col = `col' - 1
	}	
	local col = `col' + 4
}	

**************************************************
****** Household head tables  ********************
**************************************************

use "HHH_all_years_final.dta", clear

*Table 7
putexcel set "Shell Tables", sheet("Table 7") modify

local col = 3
foreach c in all cdi ghana{
	local row = 7
	capture noisily svy: regress farming dummy if `c' ==1 & Year != 2013
	mat M = r(table)
		
	local D = M[1,1]
	local B = M[1,2]
	local E = `B' + `D'
		
	excelcol `col'
	putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
	local col = `col' + 1
	excelcol `col'
	putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

	local col = `col' + 2
}


*Table 41
putexcel set "Shell Tables", sheet("Table 41") modify

local col = 3
local row = 4

levelsof region if ghana == 1 & Year == 2018, local(levels)
foreach l of local levels{
	tab region if ghana == 1 & Year == 2018 & region == "`l'"
	local N = `r(N)'
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
}

local row = `row' + 1

levelsof region if cdi == 1 & Year == 2018, local(levels)
foreach l of local levels{
	tab region if cdi == 1 & Year == 2018 & region == "`l'"
	local N = `r(N)'
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
	
}

*Table 44
putexcel set "Shell Tables", sheet("Table 44") modify

local col = 2

foreach c in cdi ghana{
local row = 3
	foreach var in acre acre_cocoa{
		tabstat `var' [fweight = fweight] if `c'==1 & Year==2018, save 
		matrix stats=r(StatTotal)
		local N = stats[1,1]
				
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
	}
local col = `col' + 1
}

//COCOA HHH surveys

keep if Year != 2008 & farming == 1

svyset [pw=cocoa_weight], strata(strata)

*Table 8
putexcel set "Shell Tables", sheet("Table 8") modify

local col = 2
	foreach country in all cdi ghana {
			
		local row = 4
			
		foreach y in 2013 2018{
			
			tabstat cocoa_weight if Year==`y' & `country'==1, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}	
			
		local row = `row' + 1
		local col = `col' - 2

		foreach var in fert pest herb {
						
			capture noisily svy: regress `var' dummy if `country'==1
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
				
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
						
			local row = `row' + 1
			local col = `col' - 1
		}		
		local col = `col' + 3
	}

*Table 34
putexcel set "Shell Tables", sheet("Table 34") modify
local col = 2

foreach country in all cdi ghana {

	local row = 4

	foreach var in fert pest herb {
					
		capture noisily svy: regress `var'_exp_ton_p10 dummy if `country'==1 & farming == 1
		mat M = r(table)
			
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
			
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1
		local col = `col' - 1
	}		
	local col = `col' + 3
}

*******************
** 2018 datasets **
*******************

use "all_surveys_2018_final.dta", clear

*Table 4

putexcel set "Shell Tables", sheet("Table 4") modify

local col = 4

foreach c in cdi ghana{
	local row = 3

	sum A2_ch if `c' == 1 & Year == 2018, detail
	local age_mean = `r(mean)'
	local age_med = `r(p50)'
	
	excelcol `col'
	putexcel `r(column)'`row' = `age_mean', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
			
	excelcol `col'
	putexcel `r(column)'`row' = `age_med', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)

	local row = `row' + 1
	
	sum gender if `c' == 1 & Year == 2018
	local N = `r(N)' 

	sum gender if gender == 2 & `c' == 1 & Year == 2018
	local male_N = `r(N)'
	local male_pct = `male_N'/`N'
	
	excelcol `col'
	putexcel `r(column)'`row' = `male_N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
			
	excelcol `col'
	putexcel `r(column)'`row' = `male_pct', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 1

	sum gender if gender == 1 & `c' == 1 & Year == 2018
	local female_N = `r(N)'
	local female_pct = `female_N'/`N'
	
	excelcol `col'
	putexcel `r(column)'`row' = `female_N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
			
	excelcol `col'
	putexcel `r(column)'`row' = `female_pct', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' + 1
}

*Table 41
putexcel set "Shell Tables", sheet("Table 41") modify

local col = 2
local row = 4
 
levelsof region_2018 if ghana == 1 & Year == 2018, local(levels)
foreach l of local levels{
	
	tab region_2018 if ghana == 1 & Year == 2018 & region_2018 == "`l'"
	local N = `r(N)'
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
}

local row = `row' + 1

levelsof region_2018 if cdi == 1 & Year == 2018, local(levels)
foreach l of local levels{
	
	tab region_2018 if cdi == 1 & Year == 2018 & region_2018 == "`l'"
	local N = `r(N)'
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
	local row = `row' + 1
}

*Table 43
putexcel set "Shell Tables", sheet("Table 43") modify
local col = 2
	
foreach y in 6 7{
	local row = 4
	
	replace place_birth_ro = 11 if place_birth_ro == .d
	replace nationality_ro = 11 if nationality_ro == .d

	foreach var in place_birth_ro nationality_ro{
		sum `var' if dum_6_7 == `y' & Year == 2018
		local tot = `r(N)'
		
		foreach x in 2 1 4 7 9 11 {
			sum `var' if dum_6_7 == `y' & `var' == `x' & Year == 2018
			local N = `r(N)'
			local pct = `N'/`tot'
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1
			
			excelcol `col'
			putexcel `r(column)'`row' = `pct', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' - 1
			local row = `row' + 1
		}
		local row = `row' + 1
	}
	local col = `col' + 2
}

*Table 70
putexcel set "Shell Tables", sheet("Table 70") modify
local col = 2

foreach i in cdi ghana {
	
	foreach var in cl_cocoa haz_cocoa { 
		local row = 5
		
		foreach y in mother_educ_sec_mo_ro father_educ_sec_mo_ro income_quintile_45_hhh cult_cocoa_5_hhh aware_cl_reg_hhh head_migrated_hhh{

			capture noisily svy: regress `var' `y' if `i'==1 & Year == 2018
			
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
			
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local row = `row' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 3				
		}
		local col = `col' + 1
	}
}

*Table 71
putexcel set "Shell Tables", sheet("Table 71") modify
local col = 2

foreach i in cdi ghana {
	
	foreach var in cl_cocoa haz_cocoa { 
		local row = 5
		
		foreach y in dist_pri_sch_1km_cl dist_jhs_sch_2km_cl dist_shs_sch_5km_cl roads_imp_cl grid_elec_comm_cl_dum num_mfi1_cl_dum {
						
			capture noisily svy: regress `var' `y' if `i'==1 & Year == 2018
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
	
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local row = `row' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 3
		}
		local col = `col' + 1
	}
}

*Table 72	
putexcel set "Shell Tables", sheet("Table 72") modify
local col = 2

foreach i in cdi ghana {
	
	foreach var in cl_cocoa haz_cocoa {
		local row = 5
		
		foreach y in toilets_inside_sch_dum drinking_water_pipe_sch_dum kitchen_sch_dum {
						
			capture noisily svy: regress `var' `y' if `i'==1 & Year == 2018
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
			
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local row = `row' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 3
		}
		local col = `col' + 1
	}
}

********************
** Child datasets **
********************

use "child_survey_2008_2013_2018_final.dta", clear

*Table 9

putexcel set "Shell Tables", sheet("Table 9") modify
local col = 3

	foreach i in cdi ghana {
	
		local row = 4
		
		capture noisily svy: regress SchoolAttendance dummy if `i'==1 & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
		
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 1		
		local row = `row' + 2
			
		foreach j in Gender2 Gender1{
			
			local col = `col' - 2
			
			svy: regress SchoolAttendance dummy if `i'==1 & `j'==1 & Year != 2013
			mat M = r(table)

			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
			
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1
			local row = `row' + 1
		
		}
	
		local row = `row' + 1
			
		foreach j in age_group1 age_group2 age_group3 {
			
			local col = `col' - 2
			
			svy: regress SchoolAttendance dummy if `i'==1 & `j'==1 & Year != 2013
			mat M = r(table)

			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
			
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1
			local row = `row' + 1
		}
		local col = `col' + 1		
	}	

*Table 10
putexcel set "Shell Tables", sheet("Table 10") modify
local row = 5

foreach i in all cdi ghana {
	
	local col = 2
	
	foreach var in workchild_f workchild_7d {
	
		foreach y in 2008 2018{
					
			tabstat weight if `i'==1 & `var'==1 & Year==`y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
		
		local row = `row' + 1
		local col = `col' - 2
		
		capture noisily svy: regress `var' dummy if `i' == 1  & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 3
		local row = `row' - 1	
	}	
	local row = `row' + 3
}

*Table 11
putexcel set "Shell Tables", sheet("Table 11") modify
local row = 5

foreach i in all cdi ghana {
	
	local col = 2
	
	foreach var in agchild_f agchild_7d {

		foreach y in 2008 2018{
					
			tabstat weight if `i'==1 & `var'==1 & Year==`y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
		
		local row = `row' + 1
		local col = `col' - 2
		
		capture noisily svy: regress `var' dummy if `i' == 1  & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
		
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 3
		local row = `row' - 1
		
		tabstat weight if `i'==1 & `var'==1 & Year==2013, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
				
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		
		tabstat `var' [fweight=fweight] if `i' == 1  & Year == 2013, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
		
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 1
		local row = `row' - 1
	}	
	local row = `row' + 3
}

*Table 12
putexcel set "Shell Tables", sheet("Table 12") modify
local col = 3

foreach i in agchild_f cl_ag {
	local row = 4
						
	foreach j in all cdi ghana {
		
		foreach y in 2008 2018 2013{	
			tabstat weight if `i' == 1 & `j' == 1 & Year == `y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
			
		local row = `row' - 3
		local col = `col' + 1
		
		capture noisily svy: regress `i' dummy if `j' == 1  & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
		
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1
		
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		
		tabstat `i' [fweight=fweight] if `j' == 1 & Year== 2013, save 
		matrix stats=r(StatTotal)
		local N = stats[1,1]

		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1
	}
	local col = `col' + 4
}

*Table 13
putexcel set "Shell Tables", sheet("Table 13") modify
local row = 5

foreach i in all cdi ghana {
	
	local col = 2
	
	foreach var in cocoachild_f cocoachild_7d {

		foreach y in 2008 2018{
					
			tabstat weight if `i'==1 & `var'==1 & Year==`y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
		
		local row = `row' + 1
		local col = `col' - 2
		
		capture noisily svy: regress `var' dummy if `i' == 1  & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
		
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 3
		local row = `row' - 1
		
		tabstat weight if `i'==1 & `var'==1 & Year==2013, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
				
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		
		tabstat `var' [fweight=fweight] if `i' == 1  & Year == 2013, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
		
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 1
		local row = `row' - 1
	}	
	local row = `row' + 3
}

*Table 14 
putexcel set "Shell Tables", sheet("Table 14") modify
local col = 3

foreach i in all cdi ghana {
	local row = 5		
	
	foreach age in age_group1 age_group2 age_group3 all {
		
		foreach y in 2008 2018{
						
			tabstat weight if `i'==1 & vio_max_cocoa ==1 & `age' == 1 & Year==`y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
			
		local row = `row' + 1
		local col = `col' - 2
			
		capture noisily svy: regress vio_max_cocoa dummy if `i'==1 & `age' == 1 & Year != 2013 
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
				
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			local col = `col' - 2
			local row = `row' + 1	
			
		capture noisily svy: regress TotalHours dummy if `i'==1 & `age' == 1 & Year != 2013 & cocoachild_f == 1 
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
					
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' - 1
			local row = `row' + 2	
	}	
		
	local col = `col' + 3
	local row = `row' - 9
}

*Table 15
putexcel set "Shell Tables", sheet("Table 15") modify

local col = 2

foreach i in all cdi ghana {

	local row = 4
	
	foreach var in land_preparation planting_activities farm_maintenance harvest_activities postharv_activities {
	
		capture noisily svy: regress `var' dummy if `i' == 1 & cocoachild_f == 1 & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
		
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

		local col = `col' - 1
		local row = `row' + 1	
	}	
	local col = `col' + 3
}

*Table 16
putexcel set "Shell Tables", sheet("Table 16") modify
local col = 3
local row = 4

foreach j in all cdi ghana {
	foreach y in 2008 2018 2013{
		capture tabstat weight if `j' == 1 & Year == `y', s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
					
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
	}
}

local col = 4

foreach i in cocoachild_f cl_cocoa haz_cocoa {
	local row = 4
						
	foreach j in all cdi ghana {
		
		foreach y in 2008 2018 2013{	
			capture tabstat weight if `i' == 1 & `j' == 1 & Year == `y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
			
		local row = `row' - 3
		local col = `col' + 1
		
		capture noisily svy: regress `i' dummy if `j' == 1  & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1
		
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		
		capture tabstat `i' [fweight=fweight] if `j' == 1 & Year== 2013, save 
		matrix stats=r(StatTotal)
		local N = stats[1,1]

		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1
	}
	local col = `col' + 4
}

*Table 17
putexcel set "Shell Tables", sheet("Table 17") modify
local col = 2

foreach i in all cdi ghana {
	
	local row = 4
	foreach j in 2008 2018{
		tabstat weight if Year==`j' & `i'==1, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
		
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 1
	}
	
	local col = `col' + 2
 	
	tabstat weight if Year== 2013 & `i'==1, s(sum) save
	matrix stats=r(StatTotal)
	local N = stats[1,1]
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' - 4
	local row = `row' + 2
	
	foreach var in V1a V2a V3a V4a V5a V6a haz_cocoa Via{

		capture noisily svy: regress `var' dummy if `i' == 1 & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 3
		
		tabstat `var' [fweight=fweight] if `i' == 1  & Year == 2013, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
		
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 4
		local row = `row' + 1
	}
	local col = `col' + 5
}

*Table 18
putexcel set "Shell Tables", sheet("Table 18") modify
local col = 2

foreach i in all cdi ghana {
	
	local row = 4
	
	foreach var in V_1 V_2 V_3 V_4 V_5 V_6 V_7 Vi {

		capture noisily svy: regress `var' dummy if `i' == 1 & cocoachild_f==1 & Year !=2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
		
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

		local col = `col' + 2
		
		tabstat `var' [fweight=fweight] if `i' == 1 & cocoachild_f==1 & Year == 2013, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
			
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 3
		local row = `row' + 1
	}
	local col = `col' + 4
}

*Table 19
putexcel set "Shell Tables", sheet("Table 19") modify
local col = 3

foreach i in all cdi ghana {
	
	local row = 4
	
	foreach var in V3_12m spray_cocoa present_cocoa enter_cocoa water_cocoa agrochem_cocoa {
	
		foreach y in 2008 2018{
					
			tabstat weight if `i'==1 & `var'==1 & Year==`y' & cocoachild_f == 1, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
		local col = `col' + 1
		
		tabstat weight if `i'==1 & `var'==1 & Year==2013 & cocoachild_f == 1, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
					
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		local col = `col' - 3
		
		capture noisily svy: regress `var' dummy if `i' == 1 & cocoachild_f == 1 & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

		local col = `col' + 2
		
		tabstat `var' [fweight=fweight] if `i'==1 & Year==2013 & cocoachild_f == 1, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
		
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 3
		local row = `row' + 1	
	}	
	local col = `col' + 4
}

*Table 20
putexcel set "Shell Tables", sheet("Table 20") modify
local col = 2
foreach i in all cdi ghana {

	local row = 4 
	
	tabstat weight if `i'==1 & Year==2018 & cocoa_hh == 1 & agchild_f==1, s(sum) save 
	matrix stats=r(StatTotal)
	local N = stats[1,1]
				
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' + 1
	
	tabstat weight if `i'==1 & Year==2018 & cocoa_hh == 0 & agchild_f==1, s(sum) save 
	matrix stats=r(StatTotal)
	local N = stats[1,1]
				
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 2
	local col = `col' - 1
	
	foreach var in F2_1_ch_m F2_2_ch_m F2_3_ch_m F2_4_ch_m F2_5_ch_m F2_6_ch_m F2_7_ch_m F2_8_ch_m F2_9_ch_m {
		
		capture noisily svy: regress `var' cocoa_hh if `i' == 1 & Year == 2018 & agchild_f==1
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

		local col = `col' - 1
		local row = `row' + 1	
	}	
	local col = `col' + 4
}

*Table 21
putexcel set "Shell Tables", sheet("Table 21") modify
local col = 2

foreach i in all cdi ghana {

	local row = 4
	
	tabstat weight if `i'==1 & Year==2018 & hazardous_12m == 1 & agchild_f==1,  s(sum) save 
	matrix stats=r(StatTotal)
	local N = stats[1,1]
				
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' + 1
	
	tabstat weight if `i'==1 & Year==2018 & hazardous_12m == 0 & agchild_f==1,  s(sum) save 
	matrix stats=r(StatTotal)
	local N = stats[1,1]
				
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 2
	local col = `col' - 1
	
	foreach var in F2_1_ch_m F2_2_ch_m F2_3_ch_m F2_4_ch_m F2_5_ch_m F2_6_ch_m F2_7_ch_m F2_8_ch_m F2_9_ch_m {
		
		capture noisily svy: regress `var' hazardous_12m if `i' == 1 & Year == 2018 & agchild_f==1
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
		local col = `col' - 1
		local row = `row' + 1	
	}	
	local col = `col' + 4
}

*Table 22
putexcel set "Shell Tables", sheet("Table 22") modify
local col = 2

foreach i in all cdi ghana {

	local row = 3
	
	tabstat weight if `i'==1 & cocoachild_f == 1 & Year == 2018, s(sum) save
	matrix stats=r(StatTotal)
	local N = stats[1,1]
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)

	local row = `row' + 2
	
	foreach var in H8_3_ch H8_1_ch H8_2_ch H8_9_ch H8_5_ch H8_4_ch  H8_6_ch H8_7_ch H8_8_ch  {
					
		tabstat `var' [fweight=fweight] if `i'==1 & cocoachild_f == 1 & Year == 2018, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
				
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1	
	}	
	local col = `col' + 1
}

*Table 23
putexcel set "Shell Tables", sheet("Table 23") modify
local col = 3

foreach i in noncocoachild_f nonagchild_f {
	local row = 4
						
	foreach j in all cdi ghana {
		
		foreach y in 2008 2018 2013{	
			tabstat weight if `i' == 1 & `j' == 1 & Year == `y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
			
		local row = `row' - 3
		local col = `col' + 1
		
		capture noisily svy: regress `i' dummy if `j' == 1  & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
	
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1
		
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		
		tabstat `i' [fweight=fweight] if `j' == 1 & Year== 2013, save 
		matrix stats=r(StatTotal)
		local N = stats[1,1]

		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1
	}
	local col = `col' + 4
}

*Table 28 & Table 29
local n = 28

foreach sheet in all cocoachild_f{
	local col = 3

	putexcel set "Shell Tables", sheet("Table `n'") modify
	foreach i in all cdi ghana {
	
		local row = 4
	
		foreach y in 2008 2018{
					
			tabstat weight if `i'==1 & SchoolAttendance == 1 & Year==`y' & `sheet'==1, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
		
		local col = `col' + 1
		
		tabstat weight if `i'==1 & SchoolAttendance == 1 & Year== 2013 & `sheet'==1, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
					
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		local col = `col' - 3
		
		capture noisily svy: regress SchoolAttendance dummy if `i'==1 & `sheet'==1  & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 2
			
		tabstat SchoolAttendance [fweight=fweight] if `i'==1 & Year==2013 & `sheet' == 1, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
		
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 2
			
		foreach j in Gender2 Gender1{
			
			local col = `col' - 3
			
			foreach y in 2008 2018{
				
				tabstat weight if `i'==1 & SchoolAttendance==1 & `j'==1 & Year==`y' & `sheet'==1, s(sum) save
				matrix stats=r(StatTotal)
				local N = stats[1,1]
				
				excelcol `col'
				putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				local col = `col' + 1
			}
			
			local col = `col' + 1
		
			tabstat weight if `i'==1 & SchoolAttendance == 1 & `j' == 1 & Year== 2013 & `sheet'==1, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
							
			local row = `row' + 1
			local col = `col' - 3
			
			svy: regress SchoolAttendance dummy if `i'==1 & `j'==1 & `sheet'==1  & Year != 2013
			mat M = r(table)

			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 2
			
			tabstat SchoolAttendance [fweight=fweight] if `i'==1 & `j' == 1 & Year==2013 & `sheet' == 1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
		
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
	
		local row = `row' + 1
			
		foreach j in age_group1 age_group2 age_group3 {
			
			local col = `col' - 3
			
			foreach y in 2008 2018{
				
				tabstat weight if `i'==1 & SchoolAttendance==1 & `j'==1 & Year==`y' & `sheet'==1, s(sum) save
				matrix stats=r(StatTotal)
				local N = stats[1,1]
				
				excelcol `col'
				putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				local col = `col' + 1
			}
			
			local col = `col' + 1
		
			tabstat weight if `i'==1 & SchoolAttendance == 1 & `j' == 1 & Year== 2013 & `sheet'==1, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
							
			local row = `row' + 1
			local col = `col' - 3
			
			svy: regress SchoolAttendance dummy if `i'==1 & `j'==1 & `sheet'==1  & Year != 2013
			mat M = r(table)

			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
			
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 2
			
			tabstat SchoolAttendance [fweight=fweight] if `i'==1 & `j' == 1 & Year==2013 & `sheet' == 1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
		
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
		local col = `col' + 1		
	}	
	local n = `n' + 1
}

*Table 30
putexcel set "Shell Tables", sheet("Table 30") modify
local col = 3

foreach var in cl_cocoa haz_cocoa {
	foreach i in all cdi ghana {
		local row = 5
							
		foreach age in age_group1 age_group2 age_group3 {
			capture noisily svy: regress SchoolAttendance dummy if `var' == 1 & `i'==1 & `age' == 1 & Year != 2013
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
			
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
			local col = `col' - 1
			local row = `row' + 1
			
			capture noisily svy: regress SchoolAttendance_no dummy if `var' == 1 & `i'==1 & `age' == 1 & Year != 2013
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
			local col = `col' - 1
		}
		local col = `col' + 4
	}
}

*Table 31
putexcel set "Shell Tables", sheet("Table 31") modify
local col = 3

foreach i in cdi ghana {
	
	local row = 4
	
	foreach var in read write math{
			tabstat weight if `var' == 1 & `i'==1 & Year== 2018  & cocoa_hh == 1, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1

			tabstat weight if `var' == 1 & `i'==1 & Year== 2018 & cocoa_hh == 0, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1

			svy: regress `var' cocoa_hh if `i'==1 & Year== 2018
			mat M = r(table)

			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' - 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
	}
	local col = `col' + 3
}	

*Table 32
putexcel set "Shell Tables", sheet("Table 32") modify
local col = 2

foreach i in all cdi ghana {
	
	local row = 4
	
	foreach var in NoSchool InterferenceSchool V7V8 {
	
		foreach y in 2008 2018{
					
			tabstat weight if `i'==1 & `var' == 1 & Year==`y' & cocoachild_f==1 & inlist(age_range_ch,1,2), s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
		local col = `col' + 2
		
		tabstat weight if `i'==1 & `var' == 1 & Year== 2013 & cocoachild_f==1 & inlist(age_range_ch,1,2), s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
				
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		local col = `col' - 4
		
		capture noisily svy: regress `var' dummy if `i'==1 & cocoachild_f==1 & inlist(age_range_ch,1,2) & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

		local col = `col' + 3
			
		tabstat `var' [fweight=fweight] if `i'==1 & cocoachild_f==1 & inlist(age_range_ch,1,2) & Year==2013, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
	
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 4
		local row = `row' + 1	
	}	
	local col = `col' + 5
}

*Table 33
putexcel set "Shell Tables", sheet("Table 33") modify
local row = 4
local col = 3

foreach i in all cdi ghana {
	foreach k in stratum1 stratum2 stratum3 all {
		foreach j in 2008 2013 2018{
			
			tabstat weight if `i' == 1 & `k'==1 & Year == `j', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1
		}
		local row = `row' + 1
		local col = `col' - 3
	}
}

local col = 6
		
foreach var in cl_cocoa haz_cocoa {
	local row = 4
	
	foreach i in all cdi ghana {
		foreach k in stratum1 stratum2 stratum3 all {
		
			svy: regress `var' dummy if `i' == 1 & `k'==1 & Year != 2013
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 3
			
			tabstat `var' [fweight= fweight] if `i' == 1 & `k'==1 & Year == 2013, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' - 4
			local row = `row' + 1
		}
	}
	local col = `col' + 5
}

*Table 36
putexcel set "Shell Tables", sheet("Table 36") modify

local row = 4 
local col = 2

tabstat weight if cdi == 1 & Year == 2018, s(sum) save
matrix stats=r(StatTotal)
local N = stats[1,1]
			
excelcol `col'
capt putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)

local row = `row' + 2

foreach var in V1_cdi_7d V2_cdi_12m V3_cdi_12m V4_cdi_12m V5_cdi_12m V6_cdi_12m V7_cdi_12m hazardous_cdi_12m Vi_cdi{
	tabstat `var' [fweight=fweight] if cdi == 1 & Year == 2018, save
	matrix stats=r(StatTotal)
	local N = stats[1,1]
				
	excelcol `col'
	capt putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

	local row = `row' + 1
}

*Table 37
putexcel set "Shell Tables", sheet("Table 37") modify

local row = 4 
local col = 2

tabstat weight if ghana == 1 & Year == 2018, s(sum) save
matrix stats=r(StatTotal)
local N = stats[1,1]
			
excelcol `col'
capt putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)

local row = `row' + 2

foreach var in V1_ghana_12m V2_ghana_12m V3_ghana_12m V4_ghana_12m V5_ghana_12m V6_ghana_12m V7_ghana_12m V8_ghana_12m V9_ghana_12m V10_ghana_12m hazardous_ghana_12m Vi_ghana {
	tabstat `var' [fweight=fweight] if ghana == 1 & Year == 2018, save
	matrix stats=r(StatTotal)
	local N = stats[1,1]
				
	excelcol `col'
	capt putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

	local row = `row' + 1
}

*Table 38
putexcel set "Shell Tables", sheet("Table 38") modify

local col = 3

foreach c in child_labor hazardous {
	local row = 3 
	foreach x in cdi ghana {
		tabstat weight if `c'_`x'_12m == 1 & `x' == 1 & Year == 2018, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
					
		excelcol `col'
		capt putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		
		tabstat `c'_`x'_12m [fweight=fweight] if `x' == 1 & Year == 2018, save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
					
		excelcol `col'
		capt putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
	}
	local col = `col' + 1
}

*Table 45
putexcel set "Shell Tables", sheet("Table 45") modify
local col = 2

foreach i in all cdi ghana {
	
	foreach j in 2008 2013 2018 {
		
		local row = 4
	
		tabstat weight if Year == `j' & `i' == 1 & cl_ag == 1, s(sum) save 
		matrix stats=r(StatTotal)
		local N = stats[1,1]
			
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = 7
	
		foreach k in 2 1 {
			
			capture noisily tabstat Gender`k' [fweight=fweight] if Year==`j' & `i'==1 & cl_ag==1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local row = `row' + 1			
		}
		
		local row = `row' + 1
		
		foreach k in 1 2 3 {
			
			capture noisily tabstat age_group`k' [fweight=fweight] if Year==`j' & `i'==1 & cl_ag==1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local row = `row' + 1			
		}
		local row = `row' + 1
		local col = `col' + 1
	}
}	

*Table 46
putexcel set "Shell Tables", sheet("Table 46") modify
local col = 3

foreach i in all cdi ghana {
	local row = 4
						
	foreach age in age_group1 age_group2 age_group3 {
		
		foreach y in 2008 2018{	
			
			tabstat SchoolAttendance [fweight=fweight] if cl_ag == 1 & `i'==1 & `age' == 1 & Year==`y', save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1
		}
			
		local row = `row' + 2
		local col = `col' - 2
	}
	local col = `col' + 2
}

*Table 47
putexcel set "Shell Tables", sheet("Table 47") modify
local row = 3
						
		foreach age in all age_group1 age_group2 age_group3 {
		local col = 2
		
		capture noisily svy: regress child_labor_12m SchoolAttendance if `age' == 1 & Year == 2018
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 2
		local row = `row' + 1
	}

*Table 48
local row = 5
putexcel set "Shell Tables", sheet("Table 48") modify

foreach gender in Gender2 Gender1{

	local col = 3

	foreach i in cdi ghana {
						
		foreach age in age_group1 age_group2 age_group3 all {
		
			foreach y in 2008 2018{
						
				tabstat weight if `i'==1 &  vio_max_cocoa==1 & `age' == 1 & Year==`y' & `gender'==1, s(sum) save
				matrix stats=r(StatTotal)
				local N = stats[1,1]
						
				excelcol `col'
				putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				local col = `col' + 1
			}
			
			local row = `row' + 1
			local col = `col' - 2
			
		capture noisily svy: regress vio_max_cocoa dummy if `i'==1 & `age' == 1  & `gender'==1 & Year != 2013 
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
	
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' - 1
			local row = `row' + 1	
			
		capture noisily svy: regress TotalHours dummy if `i'==1 & `age' == 1 & `gender'==1 & Year != 2013 & cocoachild_f == 1 
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' - 1
			local row = `row' + 1			
		}	
		local col = `col' + 3
		local row = `row' - 12
	}
	local row = `row' + 13
}

*Table 49
putexcel set "Shell Tables", sheet("Table 49") modify
local col = 3

foreach i in light_cocoa legal_cocoa {
	local row = 4
						
	foreach j in all cdi ghana {
		
		foreach y in 2008 2018 2013{	
			capture tabstat weight if `i' == 1 & `j' == 1 & Year == `y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
			
		local row = `row' - 3
		local col = `col' + 1
		
		capture noisily svy: regress `i' dummy if `j' == 1  & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1
		
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		
		capture tabstat `i' [fweight=fweight] if `j' == 1 & Year== 2013, save 
		matrix stats=r(StatTotal)
		local N = stats[1,1]

		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1
	}
	local col = `col' + 4
}

*Table 50
putexcel set "Shell Tables", sheet("Table 50") modify
local col = 2

foreach i in all cdi ghana {
	local row = 5
	
	foreach var in Cocoa12Mo_LandClearing Cocoa12Mo_FellingChopping Cocoa12Mo_Burning Cocoa12Mo_Stumping  ///
	dummy Cocoa12Mo_PreparationSeedlings Cocoa12Mo_HolingSeedlings  Cocoa12Mo_SowingStake ///
	dummy Cocoa12Mo_Weeding Cocoa12Mo_SprayingInsecticides Cocoa12Mo_Fertilizer Cocoa12Mo_Fungicides Cocoa12Mo_WaterCarrying Cocoa12Mo_SanitationPruning Cocoa12Mo_MistletonControl ///
	dummy Cocoa12Mo_PluckingCocoa Cocoa12Mo_GatheringPods Cocoa12Mo_PodBreaking ///
	dummy Cocoa12Mo_CartingBeans Cocoa12Mo_DryingBeans Cocoa12Mo_CartingBeansShed {
		
		capture noisily svy: regress `var'_m dummy if `i' == 1 & Year != 2013
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1	
	}	
	local col = `col' + 3
}

*Table 51
putexcel set "Shell Tables", sheet("Table 51") modify
local col = 2
local row = 5

foreach var in cl_cocoa haz_cocoa {
	foreach i in all cdi ghana {
		foreach j in 2008 2018 {
			tabstat weight if Year == `j' & `i' == 1 & `var' == 1, s(sum) save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
				
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1
		}
		local col = `col' + 2
		
		tabstat weight if Year == 2013 & `i' == 1 & `var' == 1, s(sum) save 
		matrix stats=r(StatTotal)
		local N = stats[1,1]
				
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 2
		local col = `col' - 4
		
		foreach k in 2 1 {
				
			capture noisily svy: regress Gender`k' dummy if `var' == 1 & `i' == 1 & Year != 2013
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 3
				
			capture noisily tabstat Gender`k' [fweight=fweight] if Year==2013 & `i'==1 & `var'==1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1	
			local col = `col' - 4
		}
			
		local row = `row' + 1
			
		foreach k in 1 2 3 {
				
			capture noisily svy: regress age_group`k' dummy if `var' == 1 & `i' == 1 & Year != 2013
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 3
				
			capture noisily tabstat age_group`k' [fweight=fweight] if Year==2013 & `i'==1 & `var'==1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1	
			local col = `col' - 4			
		}	
		local row = `row' - 8
		local col = `col' + 5
	}	
	local row = 17
	local col = 2
}

*Table 52
putexcel set "Shell Tables", sheet("Table 52") modify
local col = 2

foreach i in all cdi ghana {
	
	local row = 5
	
	foreach k in 1 2 3{
	
		foreach var in V1a V2a V3a V4a V5a V6a haz_cocoa Via{

			capture noisily svy: regress `var' dummy if age_group`k' == 1 & `i' == 1 & Year != 2013
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
			
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 3
			
			tabstat `var' [fweight=fweight] if `i' == 1  & Year == 2013 & age_group`k' == 1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' - 4
			local row = `row' + 1
		}
		local row = `row' + 1
	}
	local col = `col' + 5
}

*Table 53
putexcel set "Shell Tables", sheet("Table 53") modify
local col = 2

foreach i in all cdi ghana {
	
	local row = 5
	
	foreach k in 2 1 {
	
		foreach var in V1a V2a V3a V4a V5a V6a haz_cocoa Via{

			capture noisily svy: regress `var' dummy if Gender`k' == 1 & `i' == 1 & Year != 2013
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 3
			
			tabstat `var' [fweight=fweight] if `i' == 1  & Year == 2013 & Gender`k' == 1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' - 4
			local row = `row' + 1
		}
		local row = `row' + 1
	}
	local col = `col' + 5
}

*Table 54
putexcel set "Shell Tables", sheet("Table 54") modify
local col = 2
local row = 5

foreach i in all cdi ghana {		
		foreach k in 1 2 3 {
				
			capture noisily svy: regress age_group`k' dummy if V3_cocoa == 1 & `i' == 1 & Year != 2013
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 2
				
			capture noisily tabstat age_group`k' [fweight=fweight] if Year==2013 & `i'==1 & V3_cocoa==1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1	
			local col = `col' - 3
		}
			
		local row = `row' + 1
			
		foreach k in 2 1 {
				
			capture noisily svy: regress Gender`k' dummy if V3_cocoa == 1 & `i' == 1 & Year != 2013
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 2
				
			capture noisily tabstat Gender`k' [fweight=fweight] if Year==2013 & `i'==1 & V3_cocoa==1, save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1	
			local col = `col' - 3			
		}	
		local row = `row' - 6
		local col = `col' + 4
	}
	
*Table 55
putexcel set "Shell Tables", sheet("Table 55") modify

local row = 4

foreach var in child_labor_12m hazardous_12m {
	local col = 3
	foreach  i in cdi ghana {
			tabstat weight if `i' == 1 & `var' == 1 & Year == 2018 & cocoa_hh == 1, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			capt putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1
			
			tabstat weight if `i' == 1 & `var' == 1 & Year == 2018 & cocoa_hh == 0, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			capt putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
			local col = `col' - 1
			
			capture noisily svy: regress `var' cocoa_hh if `i' == 1 & Year == 2018
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 3
			local row = `row' - 1
	}
	local row = `row' + 2
}

*Table 64
putexcel set "Shell Tables", sheet("Table 64") modify

local col = 3
local row = 4

foreach j in all cdi ghana {
	capture tabstat weight if `j' == 1 & Year == 2018, s(sum) save
	matrix stats=r(StatTotal)
	local N = stats[1,1]
				
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 2
}

local col = 4

foreach i of newlist agchild cl_ag1 haz_ag1 {
	local row = 4
						
	foreach j in all cdi ghana {
		
		capture tabstat weight if `j' == 1 & Year == 2018 & `i'_7d == 1, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
					
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		
		capture tabstat weight if `j' == 1 & Year == 2018 & `i'_12m == 1, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
					
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' - 1
		local col = `col' + 1
		
		tabstat `i'_7d [fweight=fweight] if `j'==1 & Year==2018, save
		
		matrix stats=r(StatTotal)
		local B = stats[1,1]
		
		tabstat `i'_12m [fweight=fweight] if `j'==1 & Year==2018, save
		
		matrix stats=r(StatTotal)
		local E = stats[1,1]

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1
		
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
		local col = `col' - 1
	}
	local col = `col' + 4
}
	
*Table 65
putexcel set "Shell Tables", sheet("Table 65") modify
local col = 2

foreach i in all cdi ghana {
	local row = 4
	
	tabstat weight if Year== 2018 & `i'==1, s(sum) save
	matrix stats=r(StatTotal)
	local N = stats[1,1]
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 2
	
	forvalues x = 1/6{
		tabstat V`x'_7d [fweight=fweight] if `i'==1 & Year==2018, save
		
		matrix stats=r(StatTotal)
		local B = stats[1,1]
		
		tabstat V`x'_12m [fweight=fweight] if `i'==1 & Year==2018, save
		
		matrix stats=r(StatTotal)
		local E = stats[1,1]
		
		excelcol `col'
		putexcel `r(column)'`row' = "`B'", nformat(percent) hcenter font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 1
		
		excelcol `col'
		putexcel `r(column)'`row' = "`E'", nformat(percent) hcenter font("Gill Sans MT" , 10 , black) border(all, thin, black)

		local col = `col' - 1
		local row = `row' + 1
	}
	
		tabstat hazardous_7d [fweight=fweight] if `i'==1 & Year==2018, save
		
		matrix stats=r(StatTotal)
		local B = stats[1,1]
		
		tabstat hazardous_12m [fweight=fweight] if `i'==1 & Year==2018, save
		
		matrix stats=r(StatTotal)
		local E = stats[1,1]
	
	excelcol `col'
	putexcel `r(column)'`row' = "`B'",  nformat(percent) hcenter font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' + 1
	
	excelcol `col'
	putexcel `r(column)'`row' = "`E'",  nformat(percent) hcenter font("Gill Sans MT" , 10 , black) border(all, thin, black)

	local col = `col' - 1
	local row = `row' + 1
	
	tabstat Vi_7d [fweight=fweight] if `i'==1 & Year==2018, save
		
		matrix stats=r(StatTotal)
		local B = stats[1,1]
		
		tabstat Vi [fweight=fweight] if `i'==1 & Year==2018, save
		
		matrix stats=r(StatTotal)
		local E = stats[1,1]

	excelcol `col'
	putexcel `r(column)'`row' = "`B'",  nformat(percent) hcenter font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' + 1
	
	excelcol `col'
	putexcel `r(column)'`row' = "`E'",  nformat(percent) hcenter font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local col = `col' + 3
}

*Table 66
putexcel set "Shell Tables", sheet("Table 66") modify

local col = 2

foreach c in all cdi ghana{
	local row = 4
	
	tabstat weight if Year== 2018 & `c'==1 & cocoachild_f == 1, s(sum) save 
	matrix stats=r(StatTotal)
	local N = stats[1,1]
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 2
		
	foreach var in D14A_1_ch D14A_2_ch D14A_3_ch {
	
		forvalues x = 0/3 {
			tabstat `var'_`x' [fweight=fweight] if `c' == 1 & Year == 2018 & cocoachild_f == 1, save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			capt putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 1
		}
		local row = `row' + 1
		local col = `col' - 4
	}
	local col = `col' + 4
}

*Table 67
putexcel set "Shell Tables", sheet("Table 67") modify

local col = 2

foreach c in all cdi ghana{
	local row = 4
	
	tabstat weight if Year== 2018 & `c'==1 & cocoachild_f == 1, s(sum) save 
	matrix stats=r(StatTotal)
	local N = stats[1,1]
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 2
		
	foreach var in G2B2_1_ch G2B2_2_ch G2B2_3_ch G2B2_4_ch G2B2_5_ch G2B2_6_ch {
	
		forvalues x = 0/3 {
			tabstat `var'_`x' [fweight=fweight] if `c' == 1 & Year == 2018 & cocoachild_f == 1, save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			capt putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 1
		}
		local row = `row' + 1
		local col = `col' - 4
	}
	local col = `col' + 4
}

*Table 68
putexcel set "Shell Tables", sheet("Table 68") modify

local col = 2

foreach c in all cdi ghana{
	local row = 4
	
	tabstat weight if Year== 2018 & `c'==1 & cocoachild_f == 1, s(sum) save 
	matrix stats=r(StatTotal)
	local N = stats[1,1]
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 2
		
	foreach var in H4B_1_ch H4B_2_ch H4B_3_ch D14A_5_ch H11A_1_ch H11A_2_ch {
	
		forvalues x = 0/3 {
			tabstat `var'_`x' [fweight=fweight] if `c' == 1 & Year == 2018 & cocoachild_f == 1, save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			capt putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 1
		}
		local row = `row' + 1
		local col = `col' - 4
	}
	local col = `col' + 4
}

*Table 69
putexcel set "Shell Tables", sheet("Table 69") modify

local col = 2

foreach c in all cdi ghana{
	local row = 4
	
	tabstat weight if Year== 2018 & `c'==1 & cocoachild_f == 1, s(sum) save 
	matrix stats=r(StatTotal)
	local N = stats[1,1]
	
	excelcol `col'
	putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
	
	local row = `row' + 2
		
	foreach var in I2A_1_ch I2A_2_ch I2A_3_ch I2A_4_ch I2A_5_ch {
	
		forvalues x = 0/3 {
			tabstat `var'_`x' [fweight=fweight] if `c' == 1 & Year == 2018 & cocoachild_f == 1, save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			capt putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' + 1
		}
		local row = `row' + 1
		local col = `col' - 4
	}
	local col = `col' + 4
}

************************************
**** Cocoa Households 2013 2018 ****
************************************

use "child_survey_2008_2013_2018_final.dta", clear

keep if Year != 2008 & cocoa_hh == 1

svyset [pw=cocoa_weight], strata(Strata)

*Table 24
putexcel set "Shell Tables", sheet("Table 24") modify
local row = 5

foreach i in all cdi ghana {
		
	local col = 2
		
	foreach var in cocoachild_f cocoachild_7d {
		
		foreach y in 2013 2018{
						
			tabstat cocoa_weight if `i'==1 & `var'==1 & Year==`y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
			
		local row = `row' + 1
		local col = `col' - 2
			
		capture noisily svy: regress `var' dummy if `i' == 1
		mat M = r(table)
			
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
			
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `D', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 2
		local row = `row' - 1	
	}	
	local row = `row' + 3
}

*Table 25
putexcel set "Shell Tables", sheet("Table 25") modify

local col = 3
local row = 4

foreach j in all cdi ghana {
	foreach y in 2013 2018{
		tabstat cocoa_weight if `j' == 1 & Year == `y', s(sum) save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local row = `row' + 1
	}
}

local col = 4

foreach i in cocoachild_f cl_cocoa haz_cocoa {
	local row = 4
						
	foreach j in all cdi ghana {
		
		foreach y in 2013 2018 {	
			tabstat cocoa_weight if `i' == 1 & `j' == 1 & Year == `y', s(sum) save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
			
		local row = `row' - 2
		local col = `col' + 1
		
		capture noisily svy: regress `i' dummy if `j' == 1 
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local row = `row' + 1
		
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1
	}
	local col = `col' + 4
}

*Table 26
putexcel set "Shell Tables", sheet("Table 26") modify

local col = 2

foreach i in all cdi ghana {
	
	local row = 4
	foreach j in 2013 2018{
		tabstat cocoa_weight if Year == `j' & `i' == 1, s(sum) save
		matrix stats=r(StatTotal)
		local N = stats[1,1]
		
		excelcol `col'
		putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' + 1
	}
	
	local col = `col' - 2
	local row = `row' + 2
	
	foreach var in V1a V2a V3a V4a V5a V6a haz_cocoa Via{

		capture noisily svy: regress `var' dummy if `i' == 1
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'
		
		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1
	}
	local col = `col' + 3
}

*Table 27
putexcel set "Shell Tables", sheet("Table 27") modify
local col = 3

foreach i in all cdi ghana {
	
	local row = 4
	
	foreach var in V3_12m spray_cocoa present_cocoa enter_cocoa water_cocoa agrochem_cocoa {
	
		foreach y in 2013 2018{
					
			tabstat cocoa_weight if `i'==1 & `var'==1 & Year==`y' & cocoachild_f == 1, s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
					
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
		
		local row = `row' + 1
		local col = `col' - 2
		
		capture noisily svy: regress `var' dummy if `i' == 1 & cocoachild_f == 1
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1	
	}	
	local col = `col' + 3
}

*Table 56
local row = 4

putexcel set "Shell Tables.xlsx", sheet("Table 56") modify
local col = 3

foreach i in cdi ghana {
						
	foreach age in age_group1 age_group2 age_group3 all {
		
		foreach y in 2013 2018{
						
			tabstat cocoa_weight if `i'==1 & vio_max_cocoa==1 & `age' == 1 & Year==`y', s(sum) save
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			local col = `col' + 1
		}
			
		local row = `row' + 1
		local col = `col' - 2
			
		capture noisily svy: regress vio_max_cocoa dummy if `i'==1 & `age' == 1
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
	
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' - 1
			local row = `row' + 1	
			
		capture noisily svy: regress TotalHours dummy if `i'==1 & `age' == 1 & cocoachild_f == 1 
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
	
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' - 1
			local row = `row' + 1	
	}	
	local col = `col' + 3
	local row = `row' - 12
}

*Table 57
putexcel set "Shell Tables", sheet("Table 57") modify
local row = 5

foreach gender in Gender2 Gender1{
	local col = 3

	foreach i in cdi ghana {
						
		foreach age in age_group1 age_group2 age_group3 all {
		
			foreach y in 2013 2018{
						
				tabstat cocoa_weight if `i'==1 & vio_max_cocoa==1 & `age' == 1 & Year==`y' & `gender'==1, s(sum) save
				matrix stats=r(StatTotal)
				local N = stats[1,1]
						
				excelcol `col'
				putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				local col = `col' + 1
			}
			
			local row = `row' + 1
			local col = `col' - 2
			capture noisily svy: regress vio_max_cocoa dummy if `i'==1 & `age' == 1  & `gender'==1
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
					
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' - 1
			local row = `row' + 1	
			
		capture noisily svy: regress TotalHours dummy if `i'==1 & `age' == 1 & `gender'==1 & cocoachild_f == 1 
			mat M = r(table)
				
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
				
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
					
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)

			local col = `col' - 1
			local row = `row' + 1		
		}	
		local col = `col' + 3
		local row = `row' - 12
	}
	local row = `row' + 13
}

*Table 58
putexcel set "Shell Tables", sheet("Table 58") modify
local col = 2
local row = 5

foreach var in cl_cocoa haz_cocoa {
	foreach i in all cdi ghana {
		foreach j in 2013 2018 {
			tabstat cocoa_weight if Year == `j' & `i' == 1 & `var' == 1 & cocoachild_f == 1, s(sum) save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
				
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' + 1
		}
		
		local row = `row' + 2
		local col = `col' - 2
		
		foreach k in 2 1 {
				
			capture noisily svy: regress Gender`k' dummy if `var' == 1 & `i' == 1  & cocoachild_f == 1
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1	
			local col = `col' - 1
		}
			
		local row = `row' + 1
			
		foreach k in 1 2 3 {
				
			capture noisily svy: regress age_group`k' dummy if `var' == 1 & `i' == 1 & cocoachild_f == 1
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1	
			local col = `col' - 1			
		}	
		local row = `row' - 8
		local col = `col' + 4
	}	
	local row = 17
	local col = 2
}

*Table 59
putexcel set "Shell Tables", sheet("Table 59") modify

local col = 2

foreach i in all cdi ghana {
	
	local row = 5
	
	foreach k in 1 2 3{
	
		foreach var in V1a V2a V3a V4a V5a V6a haz_cocoa Via{

			capture noisily svy: regress `var' dummy if age_group`k' == 1 & `i' == 1
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' - 1
			local row = `row' + 1
		}
		local row = `row' + 1
	}
	local col = `col' + 4
}

*Table 60
putexcel set "Shell Tables", sheet("Table 60") modify

local col = 2

foreach i in all cdi ghana {
	
	local row = 5
	
	foreach k in 2 1 {
	
		foreach var in V1a V2a V3a V4a V5a V6a haz_cocoa Via{

			capture noisily svy: regress `var' dummy if Gender`k' == 1 & `i' == 1
			mat M = r(table)
			
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local col = `col' - 1
			local row = `row' + 1
			
		}
		local row = `row' + 1
	}
	local col = `col' + 4
}

*Table 61
putexcel set "Shell Tables", sheet("Table 61") modify
local col = 2

foreach i in cdi ghana {
	
	local row = 4
	
	foreach var in V_7 V_6 V_5 V_4 V_3 V_2 V_1 Vi{

		capture noisily svy: regress `var' dummy if `i' == 1 & cocoachild_f==1 
		mat M = r(table)
		
		local D = M[1,1]
		local B = M[1,2]
		local E = `B' + `D'

		excelcol `col'
		putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
		local col = `col' + 1
		excelcol `col'
		putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
		
		local col = `col' - 1
		local row = `row' + 1
	}
	local col = `col' + 3
}

*Table 62
putexcel set "Shell Tables", sheet("Table 62") modify
local col = 2
local row = 6

foreach i in all cdi ghana {
	foreach y in 2013 2018 {
		foreach k in 1 2 3 {	
			tabstat cocoa_weight if age_group`k' == 1 & V3_cocoa == 1 & `i' == 1 & Year == `y', s(sum) save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
			
			excelcol `col'
			putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
		
		local row = `row' + 1
			
		foreach k in 2 1 {	
			capt tabstat cocoa_weight if Gender`k' == 1 & V3_cocoa == 1 & `i' == 1 & Year == `y', s(sum) save 
			matrix stats=r(StatTotal)
			local N = stats[1,1]
						
			excelcol `col'
			capt putexcel `r(column)'`row' = `N', nformat(number_sep) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1
		}
		local col = `col' + 1
		local row = `row' - 6
	}
	local col = `col' + 1
}	

local row = 14

foreach var in spray_cocoa present_cocoa enter_cocoa water_cocoa agrochem_cocoa {
	local col = 2
	
	foreach  i in all cdi ghana{
		foreach k in 1 2 3 {
				
			capture noisily svy: regress age_group`k' dummy if V3_cocoa == 1 & `i' == 1 & `var' == 1
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'
	
			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1	
			local col = `col' - 1
		}
			
		local row = `row' + 1
			
		foreach k in 2 1 {
				
			capture noisily svy: regress Gender`k' dummy if V3_cocoa == 1 & `i' == 1 & `var' == 1
			mat M = r(table)
		
			local D = M[1,1]
			local B = M[1,2]
			local E = `B' + `D'

			excelcol `col'
			putexcel `r(column)'`row' = `B', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
			local col = `col' + 1
			excelcol `col'
			putexcel `r(column)'`row' = `E', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
			
			local row = `row' + 1	
			local col = `col' - 1			
		}	
		local row = `row' - 6
		local col = `col' + 3
	}	
	local row = `row' + 8
}

*Table 63
putexcel set "Shell Tables", sheet("Table 63") modify
local col = 3
foreach var in cl_cocoa haz_cocoa {
	foreach i in all cdi ghana {
		local row = 5
							
		foreach age in age_group1 age_group2 age_group3 {
			
			foreach y in 2013 2018{	
				tabstat `var' [fweight=cocoa_fweight] if SchoolAttendance == 1 & `i'==1 & `age' == 1 & Year==`y', save 
				matrix stats=r(StatTotal)
				local N = stats[1,1]
							
				excelcol `col'
				putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
				local row = `row' + 1
				
				tabstat `var' [fweight=cocoa_fweight] if SchoolAttendance == 0 & `i'==1  & `age' == 1 & Year==`y', save 
				matrix stats=r(StatTotal)
				local N = stats[1,1]
							
				excelcol `col'
				putexcel `r(column)'`row' = `N', nformat(percent) font("Gill Sans MT" , 10 , black) border(all, thin, black)
				
				local col = `col' + 1
				local row = `row' - 1
			}
			local row = `row' + 2
			local col = `col' - 2
		}
		local col = `col' + 2	
	}
}